==> kpogre-1.2.7.tar.gz: kpogre-1.2.7/kpogre/DbObjects/kpgviewsfolder.h <==
/***************************************************************************
                          kpgviewsfolder  -  description
                             -------------------
    begin                : Ne no 1 2004
    copyright            : (C) 2004 by Lumir Vanek
    email                : lvanek@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef KPGVIEWSFOLDER_H
#define KPGVIEWSFOLDER_H

#include "kpgitemsfolder.h"

class KPGSchema;

/**
Items that hold views list

@author Lumir Vanek
*/

class KPGConnection;

class KPGViewsFolder : public KPGItemsFolder
{
public:
    KPGViewsFolder(KPGSchema *, pqxx::oid);
    ~KPGViewsFolder();

		virtual eNodeType type() const { return nodeFolderViews; }
		bool refresh(pqxx::work &);
		void displayProperties(QWidget *);
		pqxx::result resultViews() const { return m_pqxxResultViews; }
			
protected:
  // results that will be displaied in properties window
  pqxx::result m_pqxxResultViews;
	
	// Parent namespace OID
	pqxx::oid m_oidNameSpace;
};

#endif

==> kpogre_1.6.2.orig.tar.gz: kpogre-1.6.2/kpogre/DbObjects/kpgviewsfolder.h <==
/***************************************************************************
                          kpgviewsfolder  -  description
                             -------------------
    begin                : Ne no 1 2004
    copyright            : (C) 2004 by Lumir Vanek
    email                : lvanek@users.sourceforge.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef KPGVIEWSFOLDER_H
#define KPGVIEWSFOLDER_H

#include "kpgitemsfolder.h"

class KPGSchema;
class KPGConnection;

/**
  * Items that hold dastabase views list
  *
  * @author Lumir Vanek
  */
class KPGViewsFolder : public KPGItemsFolder
{
public:
    KPGViewsFolder(KPGSchema *, pqxx::oid);
    ~KPGViewsFolder();

	virtual eNodeType type() const { return nodeFolderViews; }
	
	// Refresh item, and also childs objects
	void refresh() throw(const KPGSqlException &);
	
	const pqxx::result & resultViews() const { return m_pqxxResultViews; }
			
protected:
  	// results that will be displaied in properties window
  	pqxx::result m_pqxxResultViews;
	
	// Parent namespace OID
	pqxx::oid m_oidNameSpace;
};

#endif
